/**
 * cf_file.c
 */
#include "cf_file.h"

#ifdef _WIN32
# include <io.h>
#else // #ifdef _WIN32
# include <unistd.h>
#endif // #ifdef _WIN32

int
CF_File_Open (const char	* path,
			  const int		flag)
{
	int result = open (path, flag, 0);

	if (result < 0)
		return CF_ERROR_FILE_OPEN;

	return result;
}

int
CF_File_Create (const char * path)
{
	int result = open (path, O_CREAT | O_WRONLY | O_TRUNC, 0);

	if (result < 0)
		return CF_ERROR_FILE_CREATE;

	return result;
}

int
CF_File_Close (const int fd)
{
	int result = 0;

	if (fd < 0)
		return CF_ERROR_FILE_INVALID_ARGS;

	result = close (fd);

	if (result < 0)
		return CF_ERROR_FILE_CLOSE;

	return CF_OK;
}

int
CF_File_Read (const int		fd,
			  void			* buf,
			  const size_t	len)
{
	int result = (int) read (fd, buf, len);

	if (result < 0)
		return CF_ERROR_FILE_READ;

	return CF_OK;
}

int
CF_File_Write (const int	fd,
			   const void	* buf, 
			   const size_t	len)
{
	int result = (int) write (fd, buf, len);

	if (result != len)
	  return CF_ERROR_FILE_WRITE;

	return CF_OK;
}

int
CF_File_GetSize (const int fd)
{
	int result = (int) lseek (fd, 0, SEEK_END);

	if (result < 0 || lseek (fd, 0, SEEK_SET) < 0)
		return CF_ERROR_FILE_GET_SIZE;

	return result;
}
